==> infima_client-0.45.0-py3-none-any.whl: infima_client/models/pool_summaries.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_summary_item import PoolSummaryItem
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolSummaries")


@attr.s(auto_attribs=True)
class PoolSummaries:
    """  """

    summaries: Union[Unset, List[PoolSummaryItem]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        summaries: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.summaries, Unset):
            summaries = []
            for summaries_item_data in self.summaries:
                summaries_item = summaries_item_data.to_dict()

                summaries.append(summaries_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if summaries is not UNSET:
            field_dict["summaries"] = summaries

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        summaries = []
        _summaries = d.pop("summaries", UNSET)
        for summaries_item_data in _summaries or []:
            summaries_item = PoolSummaryItem.from_dict(summaries_item_data)

            summaries.append(summaries_item)

        pool_summaries = cls(
            summaries=summaries,
        )

        pool_summaries.additional_properties = d
        return pool_summaries

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.59.0-py3-none-any.whl: infima_client/models/pool_summaries.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.pool_service_get_summaries_response_200_pool_summary import (
    PoolService_GetSummariesResponse_200PoolSummary,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolSummaries")


@attr.s(auto_attribs=True)
class PoolSummaries:
    """  """

    summaries: Union[
        Unset, List[PoolService_GetSummariesResponse_200PoolSummary]
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        summaries: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.summaries, Unset):
            summaries = []
            for summaries_item_data in self.summaries:
                summaries_item = summaries_item_data.to_dict()

                summaries.append(summaries_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if summaries is not UNSET:
            field_dict["summaries"] = summaries

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        summaries = []
        _summaries = d.pop("summaries", UNSET)
        for summaries_item_data in _summaries or []:
            summaries_item = PoolService_GetSummariesResponse_200PoolSummary.from_dict(
                summaries_item_data
            )

            summaries.append(summaries_item)

        pool_summaries = cls(
            summaries=summaries,
        )

        pool_summaries.additional_properties = d
        return pool_summaries

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
